@@ -8,12 +8,12 @@
 
 using namespace std;
 
-static const char *singletags[] = {"imagedata", "colspec", "spanspec",
+static const char *singletags[] = {"beginpage","imagedata", "colspec", "spanspec",
                                    "anchor", "xref", "area",
                                    "footnoteref", "void", "inlinegraphic",
                                    "glosssee", "graphic", "xi:include",
                                    0};
-static const char *cuttingtags[] = {"trans_comment", "para", "title", "term",
+static const char *cuttingtags[] = {"bridgehead", "trans_comment", "para", "title", "term",
                                     "entry", "contrib", "keyword", "example",
                                     "note", "footnote", "caution",
                                     "informalexample", "remark", "comment",
@@ -41,7 +41,8 @@ static const char *cuttingtags[] = {"trans_comment", "para", "title", "term",
                                     "refmiscinfo", "refsect2", "refsect3", "refsect1info",
                                     "refsect2info", "refsect3info", "refsection", "refsectioninfo",
                                     "refsynopsisdiv", "refsysnopsisdivinfo", "remark",
-                                    "revdescription", "glossentry",
+                                    "revdescription", "glossentry", "partinfo", 
+				    "segmentedlist", "segtitle", "seg", "seglistitem", "screenco",
                                     0};
 static const char *literaltags[] = {"literallayout", "synopsis", "screen",
 				    "programlisting", 0};
@@ -625,7 +626,7 @@ bool StructureParser::endElement( const QString& , const QString&, const QString
 
             MsgList messages = splitMessage(m);
             for (MsgList::Iterator it = messages.begin();
-                 it != messages.end(); it++)
+                 it != messages.end(); ++it)
             {
 #ifdef POXML_DEBUG
                 qDebug("parser '%s' %d '%s' %d:%d", (*it).msgid.latin1(), (*it).lines.first().offset, message.mid((*it).lines.first().offset, 15).latin1(), (*it).lines.first().start_line, (*it).lines.first().start_col);
