@@ -24,8 +24,7 @@
 #include <qregexp.h>
 #include <qtextstream.h>
 
-ASWriter::ASWriter( UMLDoc *parent, const char *name )
-        :SimpleCodeGenerator( parent, name) {
+ASWriter::ASWriter() {
 }
 
 ASWriter::~ASWriter() {}
@@ -35,7 +34,7 @@ void ASWriter::writeClass(UMLClassifier *c)
 {
     if(!c)
     {
-        kdDebug()<<"Cannot write class of NULL concept!" << endl;
+        kDebug()<<"Cannot write class of NULL concept!" << endl;
         return;
     }
 
@@ -51,7 +50,7 @@ void ASWriter::writeClass(UMLClassifier *c)
     }
 
     QFile fileas;
-    if(!openFile(fileas,fileName+".as"))
+    if(!openFile(fileas,fileName))
     {
         emit codeGenerated(c, false);
         return;
@@ -75,15 +74,14 @@ void ASWriter::writeClass(UMLClassifier *c)
 
 
     //write includes
-    UMLClassifierList includes;
+    UMLPackageList includes;
     findObjectsRelated(c,includes);
-    UMLClassifier *conc;
-    for(conc = includes.first(); conc ;conc = includes.next())
+    for (UMLPackage *conc = includes.first(); conc; conc = includes.next())
     {
         QString headerName = findFileName(conc, ".as");
         if ( !headerName.isEmpty() )
         {
-            as << "#include \"" << findFileName(conc,".as") << ".as\"" << m_endl;
+            as << "#include \"" << findFileName(conc,".as") << "\"" << m_endl;
         }
     }
     as << m_endl;
@@ -244,7 +242,7 @@ void ASWriter::writeClass(UMLClassifier *c)
 void ASWriter::writeOperations(QString classname, UMLOperationList *opList, QTextStream &as)
 {
     UMLOperation *op;
-    UMLAttributeList *atl;
+    UMLAttributeList atl;
     UMLAttribute *at;
 
     for(op = opList->first(); op; op = opList->next())
@@ -252,14 +250,14 @@ void ASWriter::writeOperations(QString classname, UMLOperationList *opList, QTex
         atl = op -> getParmList();
         //write method doc if we have doc || if at least one of the params has doc
         bool writeDoc = forceDoc() || !op->getDoc().isEmpty();
-        for(at = atl->first(); at ; at = atl -> next())
+        for (at = atl.first(); at ; at = atl.next())
             writeDoc |= !at->getDoc().isEmpty();
 
         if( writeDoc )  //write method documentation
         {
             as << "/**" << m_endl << formatDoc(op->getDoc()," * ");
 
-            for(at = atl->first(); at ; at = atl -> next())  //write parameter documentation
+            for (at = atl.first(); at; at = atl.next())  //write parameter documentation
             {
                 if(forceDoc() || !at->getDoc().isEmpty())
                 {
@@ -272,9 +270,9 @@ void ASWriter::writeOperations(QString classname, UMLOperationList *opList, QTex
 
         as << classname << ".prototype." << cleanName(op->getName()) << " function " << "(";
 
-        int i= atl->count();
+        int i= atl.count();
         int j=0;
-        for (at = atl->first(); at ;at = atl->next(),j++)
+        for (at = atl.first(); at; at = atl.next(),j++)
         {
             as << cleanName(at->getName())
             << (!(at->getInitialValue().isEmpty()) ? (QString(" = ")+at->getInitialValue()) : QString(""))
@@ -289,20 +287,8 @@ void ASWriter::writeOperations(QString classname, UMLOperationList *opList, QTex
 /**
  * returns "ActionScript"
  */
-QString ASWriter::getLanguage() {
-    return "ActionScript";
-}
-
-/**
- * checks whether type is "ASWriter"
- *
- * @param type
- */
-bool ASWriter::isType (QString & type)
-{
-    if(type == "ASWriter")
-        return true;
-    return false;
+Uml::Programming_Language ASWriter::getLanguage() {
+    return Uml::pl_ActionScript;
 }
 
 const QStringList ASWriter::reservedKeywords() const {
