@@ -29,7 +29,7 @@ class ASWriter : public SimpleCodeGenerator {
     Q_OBJECT
 public:
 
-    ASWriter( UMLDoc* parent, const char* name = 0 );
+    ASWriter();
     virtual ~ASWriter();
 
     /**
@@ -38,17 +38,10 @@ public:
       */
     virtual void writeClass(UMLClassifier *c);
 
-    /**
-     * checks whether type is "ASWriter"
-     *
-     * @param type
-     */
-    virtual bool isType (QString & type);
-
     /**
      * returns "ActionScript"
      */
-    virtual QString getLanguage();
+    virtual Uml::Programming_Language getLanguage();
 
     /**
      * get list of reserved keywords
