@@ -2,7 +2,7 @@
     begin               : Thu Jul 26 2005
     copyright           : (C) 2005 by Rene Meyer
     email               : rene.meyer@sturmit.de
-      (C) 2006  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+      (C) 2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net> 
  ***************************************************************************/
 
 /***************************************************************************
@@ -96,19 +96,19 @@ TclWriter::writeClass(UMLClassifier * c)
 {
 
     if (!c) {
-        kdDebug() << "Cannot write class of NULL concept!\n";
+        kDebug() << "Cannot write class of NULL concept!\n";
         return;
     }
     QFile           fileh, filetcl;
 
     // find an appropriate name for our file
-    QString         fileName = findFileName(c, ".tclbody");
+    QString         fileName = findFileName(c, ".tcl");
     if (fileName.isEmpty()) {
         emit            codeGenerated(c, false);
         return;
     }
 
-    if (!openFile(fileh, fileName + ".tcl")) {
+    if (!openFile(fileh, fileName)) {
         emit            codeGenerated(c, false);
         return;
     }
@@ -137,7 +137,7 @@ TclWriter::writeClass(UMLClassifier * c)
             need_impl = false;
     }
     if (need_impl) {
-        if (!openFile(filetcl, fileName + ".tclbody")) {
+        if (!openFile(filetcl, fileName + "body")) {
             emit            codeGenerated(c, false);
             return;
         }
@@ -165,7 +165,7 @@ TclWriter::writeHeaderFile(UMLClassifier * c, QFile & fileh)
     // write header blurb
     QString         str = getHeadingFile(".tcl");
     if (!str.isEmpty()) {
-        str.replace(QRegExp("%filename%"), classifierInfo->fileName + ".tcl");
+        str.replace(QRegExp("%filename%"), classifierInfo->fileName);
         str.replace(QRegExp("%filepath%"), fileh.name());
         writeCode(str);
     }
@@ -230,7 +230,8 @@ TclWriter::writeHeaderFile(UMLClassifier * c, QFile & fileh)
     UMLTemplateList template_params = c->getTemplateList();
     if (template_params.count()) {
         writeCode("#TODO template<");
-        for (UMLTemplate * t = template_params.first(); t;) {
+        for (UMLTemplate * t = template_params.first(); t;
+                           t = template_params.next()) {
             QString         formalName = t->getName();
             QString         typeName = t->getTypeName();
             writeCode(typeName + "# " + formalName);
@@ -336,7 +337,7 @@ TclWriter::writeSourceFile(UMLClassifier * c, QFile & filetcl)
     QString         str;
     str = getHeadingFile(".tclbody");
     if (!str.isEmpty()) {
-        str.replace(QRegExp("%filename%"), classifierInfo->fileName + ".tclbody");
+        str.replace(QRegExp("%filename%"), classifierInfo->fileName + "body");
         str.replace(QRegExp("%filepath%"), filetcl.name());
         writeCode(str);
     }
@@ -362,24 +363,24 @@ TclWriter::writeSourceFile(UMLClassifier * c, QFile & filetcl)
 }
 
 void
-TclWriter::writeCode(QString text)
+TclWriter::writeCode(const QString &text)
 {
     *mStream << getIndent() << text << m_endl;
 }
 
 void
-TclWriter::writeComm(QString text)
+TclWriter::writeComm(const QString &text)
 {
-    QStringList     lines = QStringList::split("\n", text, TRUE);
+    QStringList     lines = QStringList::split("\n", text, true);
     for (uint i = 0; i < lines.count(); i++) {
         *mStream << getIndent() << "# " << lines[i] << m_endl;
     }
 }
 
 void
-TclWriter::writeDocu(QString text)
+TclWriter::writeDocu(const QString &text)
 {
-    QStringList     lines = QStringList::split("\n", text, TRUE);
+    QStringList     lines = QStringList::split("\n", text, true);
     for (uint i = 0; i < lines.count(); i++) {
         *mStream << getIndent() << "## " << lines[i] << m_endl;
     }
@@ -391,13 +392,13 @@ TclWriter::writeDocu(QString text)
 // in self-association relationship).
 void
 TclWriter::writeAssociationIncl(UMLAssociationList list, Uml::IDType myId,
-                                QString type)
+                                const QString &type)
 {
     for (UMLAssociation * a = list.first(); a; a = list.next()) {
         UMLClassifier  *classifier = NULL;
 
         writeComm(m_endl + type + m_endl + a->toString() + m_endl + a->getDoc());
-        // only use OTHER classes (e.g. we dont need to write includes for ourselves!!
+        // only use OTHER classes (e.g. we don't need to write includes for ourselves!!
         // AND only IF the roleName is defined, otherwise, its not meant to be noticed.
         if (a->getObjectId(Uml::A) == myId && !a->getRoleName(Uml::B).isEmpty()) {
             classifier = dynamic_cast < UMLClassifier * >(a->getObject(Uml::B));
@@ -409,8 +410,11 @@ TclWriter::writeAssociationIncl(UMLAssociationList list, Uml::IDType myId,
                 writeCode("namespace eval " + cleanName(classifier->getName()) +
                           " {}");
         } else {
+            // CHECK: This crashes (classifier still NULL from above)
+            /*
             writeCode("namespace eval " + cleanName(classifier->getPackage()) +
                       "::" + cleanName(classifier->getName()) + " {}");
+             */
         }
     }
 }
@@ -428,7 +432,7 @@ TclWriter::writeUse(UMLClassifier * c)
     // if different package
     if (("::"+myNs) != mNamespace) {
         if (c->getPackage().isEmpty()) {
-            writeCode("source " + findFileName(c, ".tcl") + ".tcl");
+            writeCode("source " + findFileName(c, ".tcl"));
             writeCode("namespace import ::" + cleanName(c->getName()));
         } else {
             writeCode("package require " + myNs);
@@ -437,7 +441,7 @@ TclWriter::writeUse(UMLClassifier * c)
         }
     } else {
         // source the file
-        writeCode("source " + findFileName(c, ".tcl") + ".tcl");
+        writeCode("source " + findFileName(c, ".tcl"));
     }
 }
 
@@ -463,7 +467,7 @@ TclWriter::writeConstructorSource()
     }
     writeCode("eval configure $args");
     m_indentLevel--;
-    writeCode("}" + m_endl);
+    writeCode('}' + m_endl);
 }
 
 void
@@ -479,7 +483,7 @@ void
 TclWriter::writeDestructorSource()
 {
     writeComm(mClassGlobal + "::destructor");
-    writeCode(mClassGlobal + "::destructor {} {" + m_endl + "}" + m_endl);
+    writeCode(mClassGlobal + "::destructor {} {" + m_endl + '}' + m_endl);
 }
 
 void
@@ -525,16 +529,16 @@ TclWriter::writeAttributeDecl(Uml::Visibility visibility, bool writeStatic)
     }
 
     if (list && list->count() > 0) {
-        writeComm(m_endl + scope + " " + type + " attributes" + m_endl);
+        writeComm(m_endl + scope + ' ' + type + " attributes" + m_endl);
         // write attrib declarations now
         QString         documentation;
         for (UMLAttribute * at = list->first(); at; at = list->next()) {
             documentation = at->getDoc();
             QString         varName = cleanName(at->getName());
             QString         typeName = fixTypeName(at->getTypeName());
-            writeDocu(m_endl + "@var " + scope + " " + type + " " + typeName + " " +
+            writeDocu(m_endl + "@var " + scope + ' ' + type + ' ' + typeName + ' ' +
                       varName + m_endl + documentation);
-            writeCode(scope + " " + type + " " + varName + m_endl);
+            writeCode(scope + ' ' + type + ' ' + varName + m_endl);
         }
     }
 }
@@ -542,7 +546,7 @@ TclWriter::writeAttributeDecl(Uml::Visibility visibility, bool writeStatic)
 void
 TclWriter::writeAssociationDecl(UMLAssociationList associations,
                                 Uml::Visibility permitScope, Uml::IDType id,
-                                QString /*type*/)
+                                const QString &/*type*/)
 {
     if (forceSections() || !associations.isEmpty()) {
         bool            printRoleA = false, printRoleB = false;
@@ -583,8 +587,8 @@ TclWriter::writeAssociationDecl(UMLAssociationList associations,
 }
 
 void
-TclWriter::writeAssociationRoleDecl(QString fieldClassName, QString roleName,
-                                    QString multi, QString doc, QString scope)
+TclWriter::writeAssociationRoleDecl(const QString &fieldClassName, const QString &roleName,
+                                    const QString &multi, const QString &doc, const QString &scope)
 {
     // ONLY write out IF there is a rolename given
     // otherwise its not meant to be declared in the code
@@ -594,7 +598,7 @@ TclWriter::writeAssociationRoleDecl(QString fieldClassName, QString roleName,
 
     // declare the association based on whether it is this a single variable
     // or a List (Vector). One day this will be done correctly with special
-    // multiplicity object that we dont have to figure out what it means via regex.
+    // multiplicity object that we don't have to figure out what it means via regex.
     if (multi.isEmpty() || multi.contains(QRegExp("^[01]$"))) {
         QString         fieldVarName = roleName.lower();
 
@@ -613,7 +617,7 @@ TclWriter::writeAssociationRoleDecl(QString fieldClassName, QString roleName,
     } else {
         QString         fieldVarName = roleName.lower();
 
-        // record unique occurances for later when we want to check
+        // record unique occurrences for later when we want to check
         // for initialization of this vector
         if (VectorFieldVariables.findIndex(fieldVarName) == -1)
             VectorFieldVariables.append(fieldVarName);
@@ -649,7 +653,7 @@ TclWriter::writeInitAttributeSource()
         for (UMLAttribute * at = atl->first(); at; at = atl->next()) {
             if (!at->getInitialValue().isEmpty()) {
                 varName = cleanName(at->getName());
-                writeCode("set " + varName + " " + at->getInitialValue());
+                writeCode("set " + varName + ' ' + at->getInitialValue());
             }
         }
         // Now initialize the association related fields (e.g. vectors)
@@ -668,11 +672,11 @@ TclWriter::writeInitAttributeSource()
             writeCode("set " + varName + " [list]");
         }
         // clean up
-        ObjectFieldVariables.clear();   // shouldnt be needed?
-        VectorFieldVariables.clear();   // shouldnt be needed?
+        ObjectFieldVariables.clear();   // shouldn't be needed?
+        VectorFieldVariables.clear();   // shouldn't be needed?
 
         m_indentLevel--;
-        writeCode("}" + m_endl);
+        writeCode('}' + m_endl);
     }
 }
 
@@ -729,21 +733,21 @@ TclWriter::writeOperationHeader(UMLClassifier * c, Uml::Visibility permitScope)
             code = scope + " method " + name + " {";
         }
         // method parameters
-        UMLAttributeList *atl = op->getParmList();
+        UMLAttributeList atl = op->getParmList();
         j = 0;
-        for (at = atl->first(); at; at = atl->next(), j++) {
+        for (at = atl.first(); at; at = atl.next(), j++) {
             QString         typeName = fixTypeName(at->getTypeName());
             QString         atName = cleanName(at->getName());
             if (at->getInitialValue().isEmpty()) {
                 doc +=
-                    "@param " + typeName + " " + atName + m_endl + at->getDoc() +
+                    "@param " + typeName + ' ' + atName + m_endl + at->getDoc() +
                     m_endl;
-                code += " " + atName;
+                code += ' ' + atName;
             } else {
                 doc +=
-                    "@param " + typeName + " " + atName + " (default=" +
+                    "@param " + typeName + ' ' + atName + " (default=" +
                     at->getInitialValue() + ") " + m_endl + at->getDoc() + m_endl;
-                code += " {" + atName + " " + at->getInitialValue() + "} ";
+                code += " {" + atName + ' ' + at->getInitialValue() + "} ";
             }
         }
         if (methodReturnType != "void") {
@@ -797,14 +801,14 @@ TclWriter::writeOperationSource(UMLClassifier * c, Uml::Visibility permitScope)
         writeComm(name);
         code = "body " + name + " {";
         // parameters
-        UMLAttributeList *atl = op->getParmList();
+        UMLAttributeList atl = op->getParmList();
         j = 0;
-        for (at = atl->first(); at; at = atl->next(), j++) {
+        for (at = atl.first(); at; at = atl.next(), j++) {
             QString         atName = cleanName(at->getName());
             if (at->getInitialValue().isEmpty()) {
-                code += " " + atName;
+                code += ' ' + atName;
             } else {
-                code += " {" + atName + " " + at->getInitialValue() + "} ";
+                code += " {" + atName + ' ' + at->getInitialValue() + "} ";
             }
         }
         writeCode(code += "} {");
@@ -815,7 +819,7 @@ TclWriter::writeOperationSource(UMLClassifier * c, Uml::Visibility permitScope)
             writeCode("return");
         }
         m_indentLevel--;
-        writeCode("}" + m_endl);
+        writeCode('}' + m_endl);
     }
 }
 
@@ -828,7 +832,7 @@ TclWriter::writeAttributeSource()
         QString         name = mClassGlobal + "::" + cleanName(at->getName());
 
         writeComm(name);
-        writeCode("configbody " + name + " {} {" + m_endl + "}" + m_endl);
+        writeCode("configbody " + name + " {} {" + m_endl + '}' + m_endl);
     }
 }
 
@@ -873,8 +877,8 @@ TclWriter::writeAssociationSource(UMLAssociationList associations,
 }
 
 void
-TclWriter::writeAssociationRoleSource(QString fieldClassName,
-                                      QString roleName, QString multi)
+TclWriter::writeAssociationRoleSource(const QString &fieldClassName,
+                                      const QString &roleName, const QString &multi)
 {
     // ONLY write out IF there is a rolename given
     // otherwise its not meant to be declared in the code
@@ -883,7 +887,7 @@ TclWriter::writeAssociationRoleSource(QString fieldClassName,
 
     // declare the association based on whether it is this a single variable
     // or a List (Vector). One day this will be done correctly with special
-    // multiplicity object that we dont have to figure out what it means via regex.
+    // multiplicity object that we don't have to figure out what it means via regex.
     if (multi.isEmpty() || multi.contains(QRegExp("^[01]$"))) {
         QString         fieldVarName = roleName.lower();
 
@@ -914,18 +918,18 @@ TclWriter::writeAssociationRoleSource(QString fieldClassName,
         writeCode("}");
         m_indentLevel--;
     }
-    writeCode("}" + m_endl);
+    writeCode('}' + m_endl);
 }
 
 QString
-TclWriter::fixTypeName(QString string)
+TclWriter::fixTypeName(const QString &string)
 {
     if (string.isEmpty())
         return "void";
     return string;
 }
 
-// methods like this _shouldnt_ be needed IF we properly did things thruought the code.
+// methods like this _shouldn't_ be needed IF we properly did things thruought the code.
 QString
 TclWriter::getUMLObjectName(UMLObject * obj)
 {
