@@ -1,5 +1,6 @@
 /***************************************************************************
     copyright            : (C) 2003 Brian Thomas brian.thomas@gsfc.nasa.gov
+      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net> 
 ***************************************************************************/
 
 /***************************************************************************
@@ -27,8 +28,7 @@
 #include "../umlnamespace.h"
 
 // Constructor
-XMLSchemaWriter::XMLSchemaWriter( UMLDoc *doc, const char *name )
-        : SimpleCodeGenerator ( doc, name )
+XMLSchemaWriter::XMLSchemaWriter()
 {
 
     packageNamespaceTag = "tns";
@@ -44,20 +44,8 @@ XMLSchemaWriter::~XMLSchemaWriter() {
 /**
  * returns "XMLSchema"
  */
-QString XMLSchemaWriter::getLanguage() {
-    return "XMLSchema";
-}
-
-/**
- * checks whether type is "XMLSchemaWriter"
- *
- * @param type
- */
-bool XMLSchemaWriter::isType (QString & type)
-{
-    if(type == "XMLSchemaWriter")
-        return true;
-    return false;
+Uml::Programming_Language XMLSchemaWriter::getLanguage() {
+    return Uml::pl_XMLSchema;
 }
 
 // main method for invoking..
@@ -65,7 +53,7 @@ void XMLSchemaWriter::writeClass(UMLClassifier *c)
 {
 
     if (!c) {
-        kdDebug()<<"Cannot write class of NULL classifier!\n";
+        kDebug()<<"Cannot write class of NULL classifier!\n";
         return;
     }
 
@@ -79,7 +67,7 @@ void XMLSchemaWriter::writeClass(UMLClassifier *c)
 
     // check that we may open that file for writing
     QFile file;
-    if ( !openFile(file, fileName+".xsd") ) {
+    if ( !openFile(file, fileName) ) {
         emit codeGenerated(c, false);
         return;
     }
@@ -99,7 +87,7 @@ void XMLSchemaWriter::writeClass(UMLClassifier *c)
     // 1. create the header
     QString headerText = getHeadingFile(".xsd");
     if(!headerText.isEmpty()) {
-        headerText.replace(QRegExp("%filename%"),fileName+".xsd");
+        headerText.replace(QRegExp("%filename%"),fileName);
         headerText.replace(QRegExp("%filepath%"),file.name());
     }
     if(!headerText.isEmpty())
@@ -121,9 +109,9 @@ void XMLSchemaWriter::writeClass(UMLClassifier *c)
     // the correct import statements. Leave that for later at this time.
     /*
     //only import classes in a different package as this class
-    UMLClassifierList imports;
+    UMLPackageList imports;
     findObjectsRelated(c,imports);
-    for(UMLClassifier *con = imports.first(); con ; con = imports.next())
+    for(UMLPackage *con = imports.first(); con ; con = imports.next())
         if(con->getPackage() != c->getPackage())
                 XMLschema<<"import "<<con->getPackage()<<"."<<cleanName(con->getName())<<";"<<m_endl;
     */
@@ -203,6 +191,8 @@ UMLAttributeList XMLSchemaWriter::findAttributes (UMLClassifier *c)
               case Uml::Visibility::Private:
                 // DO NOTHING! no way to print in the schema
                 break;
+              default:
+                break;
             }
         }
     }
@@ -548,15 +538,15 @@ void XMLSchemaWriter::writeComment( const QString &comment, QTextStream &XMLsche
         XMLschema<<indent<<"-->"<<m_endl;
     } else {
         // this should be more fancy in the future, breaking it up into 80 char
-        // lines so that it doesnt look too bad
+        // lines so that it doesn't look too bad
         XMLschema<<comment<<" -->"<<m_endl;
     }
 }
 
 // all that matters here is roleA, the role served by the children of this class
 // in any composition or aggregation association. In full associations, I have only
-// considered the case of "self" association, so it shouldnt matter if we use role A or
-// B to find the child class as long as we dont use BOTH roles. I bet this will fail
+// considered the case of "self" association, so it shouldn't matter if we use role A or
+// B to find the child class as long as we don't use BOTH roles. I bet this will fail
 // badly for someone using a plain association between 2 different classes. THAT should
 // be done, but isnt yet (this is why I have left role b code in for now). -b.t.
 bool XMLSchemaWriter::writeAssociationDecls(UMLAssociationList associations,
@@ -662,7 +652,7 @@ void XMLSchemaWriter::writeAssociationRoleDecl( UMLClassifier *c, const QString
 
     // Min/Max Occurs is based on whether it is this a single element
     // or a List (maxoccurs>1). One day this will be done correctly with special
-    // multiplicity object that we dont have to figure out what it means via regex.
+    // multiplicity object that we don't have to figure out what it means via regex.
     QString minOccurs = "0";
     QString maxOccurs = "unbounded";
     if (multi.isEmpty())
@@ -677,7 +667,7 @@ void XMLSchemaWriter::writeAssociationRoleDecl( UMLClassifier *c, const QString
         QStringList values = QStringList::split( QRegExp("[^\\d{1,}|\\*]"), multi);
 
         // could use some improvement here.. for sequences like "0..1,3..5,10" we
-        // dont capture the whole "richness" of the multi. Instead we translate it
+        // don't capture the whole "richness" of the multi. Instead we translate it
         // now to minOccurs="0" maxOccurs="10"
         if (values.count() > 0)
         {
@@ -714,7 +704,7 @@ void XMLSchemaWriter::writeAssociationRoleDecl( UMLClassifier *c, const QString
     // as complexTypes.
     //
     // Of course, in OO methodology, you should be able to inherit from
-    // any class, but schema just dont allow use to have full inheritence using either groups
+    // any class, but schema just don't allow use to have full inheritence using either groups
     // or complexTypes. Thus we have taken a middle rode. If someone wants to key me into a
     // better way to represent this, I'd be happy to listen. =b.t.
     //
@@ -744,12 +734,11 @@ void XMLSchemaWriter::writeAssociationRoleDecl( UMLClassifier *c, const QString
 // IF the type is "string" we need to declare it as
 // the XMLSchema Object "String" (there is no string primative in XMLSchema).
 // Same thing again for "bool" to "boolean"
-QString XMLSchemaWriter::fixTypeName(QString string)
+QString XMLSchemaWriter::fixTypeName(const QString& string)
 {
     //  string.replace(QRegExp("^string$"),schemaNamespaceTag+":string");
     //  string.replace(QRegExp("^bool$"),schemaNamespaceTag+":boolean");
-    string.prepend(schemaNamespaceTag+":");
-    return string;
+    return schemaNamespaceTag + ':' + string;
 }
 
 QString XMLSchemaWriter::fixInitialStringDeclValue(QString value, const QString &type)
@@ -782,12 +771,12 @@ QString XMLSchemaWriter::getElementGroupTypeName(UMLClassifier *c)
 }
 
 QString XMLSchemaWriter::makePackageTag (QString tagName) {
-    tagName.prepend( packageNamespaceTag + ":");
+    tagName.prepend( packageNamespaceTag + ':');
     return tagName;
 }
 
 QString XMLSchemaWriter::makeSchemaTag (QString tagName) {
-    tagName.prepend( schemaNamespaceTag + ":");
+    tagName.prepend( schemaNamespaceTag + ':');
     return tagName;
 }
 
