@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // my own header
@@ -67,7 +67,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o) : QWidget(p
     } else if (t == Uml::ot_Entity) {
         name = i18n("Entity &name:");
     } else {
-        kdWarning() << "creating class gen page for unknown widget type" << endl;
+        kWarning() << "creating class gen page for unknown widget type" << endl;
     }
     setMinimumSize(310,330);
     QVBoxLayout * topLayout = new QVBoxLayout(this);
@@ -323,7 +323,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget) : QWid
     } else if (widget->getBaseType() == Uml::wt_Node) {
         m_pNameL->setText(i18n("Node name:"));
     } else {
-        kdWarning() << "ClassGenPage called on unknown widget type" << endl;
+        kWarning() << "ClassGenPage called on unknown widget type" << endl;
     }
     m_pNameLayout->addWidget(m_pNameL, 0, 0);
 
@@ -378,8 +378,11 @@ void ClassGenPage::updateObject() {
 
         if(m_pStereoTypeCB)
             m_pObject -> setStereotype(m_pStereoTypeCB->currentText());
+        /**
+         * @todo enable the package lineedit field amd add logic for changing the package
         if(m_pPackageLE)
             m_pObject -> setPackage(m_pPackageLE -> text());
+         */
         if( m_pAbstractCB )
             m_pObject -> setAbstract( m_pAbstractCB -> isChecked() );
         //make sure unique name
