@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2005
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -29,6 +26,8 @@
 #include "../template.h"
 #include "../umldoc.h"
 #include "../dialog_utils.h"
+#include "../object_factory.h"
+#include "../stereotype.h"
 
 ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * a)
         : KDialogBase(Plain, i18n("Parameter Properties"), Help | Ok | Cancel , Ok, parent, "_PARMPROPDLG_", true, true)
@@ -61,7 +60,7 @@ ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * a)
     m_pTypeL = new QLabel(i18n("&Type:"), m_pParmGB);
     propLayout -> addWidget(m_pTypeL, 0, 0);
 
-    m_pTypeCB = new QComboBox(m_pParmGB);
+    m_pTypeCB = new KComboBox(m_pParmGB);
     propLayout -> addWidget(m_pTypeCB, 0, 1);
     m_pTypeL->setBuddy(m_pTypeCB);
 
@@ -73,9 +72,10 @@ ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * a)
                                     m_pInitialL, i18n("&Initial value:"),
                                     m_pInitialLE, initialValue );
 
-    Dialog_Utils::makeLabeledEditField( m_pParmGB, propLayout, 3,
-                                    m_pStereoTypeL, i18n("&Stereotype name:"),
-                                    m_pStereoTypeLE, m_pAtt->getStereotype() );
+    m_pStereoTypeL = new QLabel( i18n("Stereotype name:"), m_pParmGB );
+    propLayout -> addWidget(m_pStereoTypeL, 3, 0);
+    m_pStereoTypeCB = new KComboBox(true, m_pParmGB );
+    propLayout -> addWidget(m_pStereoTypeCB, 3, 1);
 
     m_pKind =  new QButtonGroup(i18n("Passing Direction"), plainPage());
     m_pKind->setExclusive(true);
@@ -121,23 +121,24 @@ ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * a)
 
     m_pTypeCB->setDuplicatesEnabled(false);//only allow one of each type in box
     m_pTypeCB->setEditable(true);
-    m_pTypeCB->setAutoCompletion(false);
+    m_pTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
+//    m_pTypeCB->setAutoCompletion(false);
 
     //add template parameters
     UMLClassifier *pConcept = dynamic_cast<UMLClassifier*>( m_pAtt->parent()->parent() );
     if (pConcept == NULL) {
-        kdError() << "ParmPropDlg: grandparent of " << m_pAtt->getName()
+        kError() << "ParmPropDlg: grandparent of " << m_pAtt->getName()
         << " is not a UMLClassifier" << endl;
     } else {
         UMLTemplateList tmplParams( pConcept->getTemplateList() );
         for (UMLTemplate *t = tmplParams.first(); t; t = tmplParams.next())
-            m_pTypeCB->insertItem( t->getName() );
+            insertType( t->getName() );
     }
     //now add the Concepts
     UMLClassifierList namesList( m_pUmldoc->getConcepts() );
     UMLClassifier * obj;
     for(obj=namesList.first(); obj!=0 ;obj=namesList.next()) {
-        m_pTypeCB->insertItem( obj->getFullyQualifiedName() );
+        insertType( obj->getFullyQualifiedName() );
     }
 
     //work out which one to select
@@ -154,21 +155,54 @@ ParmPropDlg::ParmPropDlg(QWidget * parent, UMLDoc * doc, UMLAttribute * a)
     }
 
     if (!foundType) {
-        m_pTypeCB->insertItem( type, 0 );
+        insertType( type, 0 );
         m_pTypeCB->setCurrentItem(0);
     }
 
+    // manage stereotypes
+    m_pStereoTypeCB->setDuplicatesEnabled(false); //only allow one of each type in box
+    m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
+    insertStereotype (QString("")); // an empty stereotype is the default
+    int defaultStereotype=0;
+    bool foundDefaultStereotype = false;
+    for (UMLStereotypeListIt it(m_pUmldoc->getStereotypes()); it.current(); ++it) {
+        if (!foundDefaultStereotype) {
+            if ( m_pAtt->getStereotype() == it.current()->getName()) {
+                foundDefaultStereotype = true;
+            }
+            defaultStereotype++;
+        }
+        insertStereotype (it.current()->getName());
+    }
+    // lookup for a default stereotype, if the operation doesn't have one
+    if (foundDefaultStereotype)
+        m_pStereoTypeCB->setCurrentItem(defaultStereotype);
+    else
+        m_pStereoTypeCB->setCurrentItem(-1);
+
     // set tab order
     setTabOrder(m_pKind, m_pTypeCB);
     setTabOrder(m_pTypeCB, m_pNameLE);
     setTabOrder(m_pNameLE, m_pInitialLE);
-    setTabOrder(m_pInitialLE, m_pStereoTypeLE);
-    setTabOrder(m_pStereoTypeLE, m_pIn);
+    setTabOrder(m_pInitialLE, m_pStereoTypeCB);
+    setTabOrder(m_pStereoTypeCB, m_pIn);
     setTabOrder(m_pIn, m_pDoc);
 
     m_pNameLE->setFocus();
 }
 
+void ParmPropDlg::insertType( const QString& type, int index )
+{
+    m_pTypeCB->insertItem( type, index );
+    m_pTypeCB->completionObject()->addItem( type );
+}
+
+void ParmPropDlg::insertStereotype( const QString& type, int index )
+{
+    m_pStereoTypeCB->insertItem( type, index );
+    m_pStereoTypeCB->completionObject()->addItem( type );
+}
+
 Uml::Parameter_Direction ParmPropDlg::getParmKind() {
     Uml::Parameter_Direction pk = Uml::pd_In;
     if (m_pOut->isChecked())
@@ -181,11 +215,11 @@ Uml::Parameter_Direction ParmPropDlg::getParmKind() {
 void ParmPropDlg::slotOk() {
     if (m_pAtt != NULL) {
         m_pAtt->setParmKind( getParmKind() );
-        m_pAtt->setStereotype( m_pStereoTypeLE->text() );
+        m_pAtt->setStereotype( m_pStereoTypeCB->currentText() );
         QString typeName = m_pTypeCB->currentText();
         UMLClassifier * pConcept = dynamic_cast<UMLClassifier*>( m_pAtt->parent()->parent() );
         if (pConcept == NULL) {
-            kdError() << "ParmPropDlg::slotOk: grandparent of " << m_pAtt->getName()
+            kError() << "ParmPropDlg::slotOk: grandparent of " << m_pAtt->getName()
             << " is not a UMLClassifier" << endl;
         } else {
             UMLTemplate *tmplParam = pConcept->findTemplate(typeName);
@@ -207,9 +241,9 @@ void ParmPropDlg::slotOk() {
             // Nothing found: Create a new type on the fly.
             // @todo There should be an extra dialog to decide whether to
             // create a datatype or a class. For now, we create a class.
-            kdDebug() << "ParmPropDlg::slotOk: " << typeName << " not found."
+            kDebug() << "ParmPropDlg::slotOk: " << typeName << " not found."
                 << " Creating a new class for the type." << endl;
-            UMLObject *o = m_pUmldoc->createUMLObject(Uml::ot_Class, typeName);
+            UMLObject *o = Object_Factory::createUMLObject(Uml::ot_Class, typeName);
             m_pAtt->setType(o);
         }
 
