@@ -5,24 +5,31 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
+// own header
+#include "listpopupmenu.h"
+
+// qt/kde includes
 #include <kstandarddirs.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kdebug.h>
 
-#include "listpopupmenu.h"
+// app includes
 #include "umlwidget.h"
 #include "umldoc.h"
 #include "umllistview.h"
 #include "umllistviewitem.h"
 #include "classifierwidget.h"
 #include "classifier.h"
-#include "floatingtext.h"
+#include "floatingtextwidget.h"
 #include "uml.h"
 #include "model_utils.h"
 #include "widget_utils.h"
+#include "folder.h"
 #include "umlview.h"
 #include "statewidget.h"
 #include "activitywidget.h"
@@ -135,6 +142,10 @@ ListPopupMenu::ListPopupMenu(QWidget *parent, Uml::ListView_Type type)
         mt = mt_Package;
         break;
 
+    case Uml::lvt_Subsystem:
+        mt = mt_Subsystem;
+        break;
+
     case Uml::lvt_Component:
         mt = mt_Component;
         break;
@@ -155,6 +166,10 @@ ListPopupMenu::ListPopupMenu(QWidget *parent, Uml::ListView_Type type)
         mt = mt_Enum;
         break;
 
+    case Uml::lvt_EnumLiteral:
+        mt = mt_EnumLiteral;
+        break;
+
     case Uml::lvt_Datatype:
         mt = mt_Datatype;
         break;
@@ -262,7 +277,7 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
         break;
 
     case Uml::wt_Enum:
-        m_pInsert = new KPopupMenu(this,"New");
+        m_pInsert = new KPopupMenu(this);
         m_pInsert->insertItem(SmallIcon("source"), i18n("Enum Literal..."), mt_EnumLiteral);
         insertFileNew();
         setupColor(object->getUseFillColour());
@@ -273,7 +288,7 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
         break;
 
     case Uml::wt_Entity:
-        m_pInsert = new KPopupMenu(this,"New");
+        m_pInsert = new KPopupMenu(this);
         m_pInsert->insertItem(SmallIcon("source"), i18n("Entity Attribute..."), mt_EntityAttribute);
         insertFileNew();
         setupColor(object->getUseFillColour());
@@ -341,7 +356,7 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
     case Uml::wt_State:
         pState = static_cast< StateWidget *>( object );
         if( pState -> getStateType() == StateWidget::Normal ) {
-            m_pInsert = new KPopupMenu(this,"New");
+            m_pInsert = new KPopupMenu(this);
             m_pInsert -> insertItem(SmallIcon( "filenew"), i18n("Activity..."), mt_New_Activity);
             insertFileNew();
         }
@@ -377,7 +392,7 @@ ListPopupMenu::ListPopupMenu(QWidget * parent, UMLWidget * object,
         break;
 
     case Uml::wt_Text:
-        switch( (static_cast<FloatingText*>(object))->getRole() ) {
+        switch( (static_cast<FloatingTextWidget*>(object))->getRole() ) {
         case Uml::tr_MultiB:
             insertAssocItem(i18n("Change Multiplicity..."), mt_Rename_MultiB);
             break;
@@ -491,6 +506,11 @@ void ListPopupMenu::insertStdItem(Menu_Type m)
     case mt_Import_Classes:
         insertItem(BarIcon("source_cpp"), i18n("Import Classes..."), mt_Import_Classes);
         break;
+    case mt_Package:
+        m_pInsert->insertItem(m_pixmap[pm_Package], i18n("Package"), mt_Package);
+    case mt_Subsystem:
+        m_pInsert->insertItem(m_pixmap[pm_Subsystem], i18n("Subsystem"), mt_Subsystem);
+        break;
     case mt_Component:
         m_pInsert->insertItem(m_pixmap[pm_Component], i18n("Component"), mt_Component);
         break;
@@ -562,7 +582,7 @@ void ListPopupMenu::insertStdItem(Menu_Type m)
         insertItem(SmallIcon("image"), i18n("Export as Picture..."), mt_Export_Image);
         break;
     default:
-        kdWarning() << "ListPopupMenu::insertStdItem called on unimplemented Menu_Type " << m << endl;
+        kWarning() << "ListPopupMenu::insertStdItem called on unimplemented Menu_Type " << m << endl;
         break;
     }
 }
@@ -590,7 +610,7 @@ void ListPopupMenu::insertContainerItems(bool folderAndDiagrams) {
     m_pInsert -> insertItem(m_pixmap[pm_Interface], i18n("Interface"), mt_Interface);
     m_pInsert -> insertItem(m_pixmap[pm_Datatype], i18n("Datatype"), mt_Datatype);
     m_pInsert -> insertItem(m_pixmap[pm_Enum], i18n("Enum"), mt_Enum);
-    m_pInsert -> insertItem(m_pixmap[pm_Package], i18n("Package"), mt_Package);
+    insertStdItem(mt_Package);
     if (folderAndDiagrams) {
         m_pInsert->insertItem(Widget_Utils::iconSet(Uml::dt_Class), i18n("Class Diagram..."), mt_Class_Diagram);
         m_pInsert->insertItem(Widget_Utils::iconSet(Uml::dt_State), i18n("State Diagram..."), mt_State_Diagram);
@@ -609,7 +629,7 @@ void ListPopupMenu::insertAssocItem(const QString &label, Menu_Type mt) {
 }
 
 void ListPopupMenu::insertSubmodelAction() {
-    const Settings::OptionState& ostat = UMLApp::app()->getOptionState();
+    const Settings::OptionState& ostat = Settings::getOptionState();
     if (ostat.generalState.tabdiagrams) {
         // Umbrello currently does not support External Folders
         // in combination with Tabbed Diagrams.
@@ -619,7 +639,19 @@ void ListPopupMenu::insertSubmodelAction() {
     }
     UMLListView *listView = UMLApp::app()->getListView();
     UMLListViewItem *current = static_cast<UMLListViewItem*>(listView->currentItem());
-    QString submodelFile = current->getFolderFile();
+    UMLObject *o = current->getUMLObject();
+    if (o == NULL) {
+        kError() << "ListPopupMenu::insertSubmodelAction: "
+            << current->getText() << " getUMLObject()  returns NULL" << endl;
+        return;
+    }
+    UMLFolder *f = dynamic_cast<UMLFolder*>(o);
+    if (f == NULL) {
+        kError() << "ListPopupMenu::insertSubmodelAction: "
+            << "current->getUMLObject (" << o->getName() << ") is not a Folder" << endl;
+        return;
+    }
+    QString submodelFile = f->getFolderFile();
     if (submodelFile.isEmpty())
         insertStdItem(mt_Externalize_Folder);
     else
@@ -631,7 +663,7 @@ void ListPopupMenu::makeMultiClassifierPopup(ClassifierWidget *c)
     Uml::Widget_Type type = c->getBaseType();
     ClassifierWidget *cls = NULL;
 
-    m_pShow = new KPopupMenu(this, "Show");
+    m_pShow = new KPopupMenu(this);
     m_pShow->setCheckable(true);
     if (type == Uml::wt_Class) {
         cls = static_cast<ClassifierWidget*>(c);
@@ -670,7 +702,7 @@ void ListPopupMenu::makeMultiClassifierPopup(ClassifierWidget *c)
 void ListPopupMenu::makeClassifierPopup(ClassifierWidget *c)
 {
     Uml::Widget_Type type = c->getBaseType();
-    m_pInsert = new KPopupMenu(this,"New");
+    m_pInsert = new KPopupMenu(this);
     if (type == Uml::wt_Class)
         m_pInsert->insertItem(SmallIcon( "CVpublic_var" ), i18n("Attribute..."), mt_Attribute);
     m_pInsert->insertItem( SmallIcon( "CVpublic_meth"), i18n("Operation..."), mt_Operation);
@@ -698,7 +730,7 @@ void ListPopupMenu::makeClassifierPopup(ClassifierWidget *c)
 
 void ListPopupMenu::setupColor(bool fc)
 {
-    m_pColor = new KPopupMenu( this, "Colour");
+    m_pColor = new KPopupMenu(this);
     m_pColor -> insertItem(SmallIcon( "color_line"), i18n("Line Color..."), mt_Line_Color);
     m_pColor -> insertItem(SmallIcon( "color_fill"), i18n("Fill Color..."), mt_Fill_Color);
     m_pColor -> insertItem( i18n("Use Fill Color"), mt_Use_Fill_Color);
@@ -709,7 +741,7 @@ void ListPopupMenu::setupColor(bool fc)
 
 void ListPopupMenu::setupColorSelection(bool fc)
 {
-    m_pColor = new KPopupMenu( this, "Colour");
+    m_pColor = new KPopupMenu(this);
     m_pColor -> insertItem(SmallIcon( "color_line"), i18n("Line Color..."), mt_Line_Color_Selection);
     m_pColor -> insertItem(SmallIcon( "color_fill"), i18n("Fill Color..."), mt_Fill_Color_Selection);
     m_pColor -> insertItem( i18n("Use Fill Color"), mt_Use_Fill_Color);
@@ -719,7 +751,7 @@ void ListPopupMenu::setupColorSelection(bool fc)
 }
 
 Uml::Diagram_Type ListPopupMenu::convert_MT_DT(Menu_Type mt) {
-    Uml::Diagram_Type type =  Uml::dt_Class;
+    Uml::Diagram_Type type =  Uml::dt_Undefined;
 
     switch(mt) {
     case mt_UseCase_Diagram:
@@ -740,6 +772,12 @@ Uml::Diagram_Type ListPopupMenu::convert_MT_DT(Menu_Type mt) {
     case mt_Activity_Diagram:
         type = Uml::dt_Activity;
         break;
+    case mt_Component_Diagram:
+        type = Uml::dt_Component;
+        break;
+    case mt_Deployment_Diagram:
+        type = Uml::dt_Deployment;
+        break;
     case mt_EntityRelationship_Diagram:
         type = Uml::dt_EntityRelationship;
         break;
@@ -804,10 +842,11 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
     m_pixmap[pm_Entity]      .load(dataDir+"entity.png",        "PNG");
     m_pixmap[pm_Artifact]    .load(dataDir+"artifact.png",      "PNG");
     m_pixmap[pm_Text]        .load(dataDir+"text.png",          "PNG");
+    m_pixmap[pm_Subsystem]   .load(dataDir+"subsystem.png",     "PNG");
 
     switch(type) {
     case mt_Logical_View:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
         insertContainerItems(true);
         insertSeparator();
         insertStdItem(mt_Paste);
@@ -819,8 +858,9 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_Component_View:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
         insertStdItem(mt_Component_Folder);
+        insertStdItem(mt_Subsystem);
         insertStdItem(mt_Component);
         insertStdItem(mt_Artifact);
         insertStdItem(mt_Component_Diagram);
@@ -833,7 +873,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_Deployment_View:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
         insertStdItem(mt_Deployment_Folder);
         insertStdItem(mt_Node);
         insertStdItem(mt_Deployment_Diagram);
@@ -846,7 +886,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_EntityRelationship_Model:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
         insertStdItem(mt_EntityRelationship_Folder);
         insertStdItem(mt_Entity);
         insertStdItem(mt_EntityRelationship_Diagram);
@@ -859,7 +899,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_UseCase_View:
-        m_pInsert = new KPopupMenu(this,"New");
+        m_pInsert = new KPopupMenu(this);
         insertStdItem(mt_UseCase_Folder);
         insertStdItem(mt_Actor);
         insertStdItem(mt_UseCase);
@@ -875,7 +915,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_Logical_Folder:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
         insertContainerItems(true);
         insertStdItems();
         insertStdItem(mt_Import_Classes);
@@ -886,8 +926,9 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_Component_Folder:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
         insertStdItem(mt_Component_Folder);
+        insertStdItem(mt_Subsystem);
         insertStdItem(mt_Component);
         insertStdItem(mt_Artifact);
         insertStdItem(mt_Component_Diagram);
@@ -900,7 +941,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_Deployment_Folder:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
         insertStdItem(mt_Deployment_Folder);
         insertStdItem(mt_Node);
         insertStdItem(mt_Deployment_Diagram);
@@ -913,7 +954,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_UseCase_Folder:
-        m_pInsert = new KPopupMenu(this,"New");
+        m_pInsert = new KPopupMenu(this);
         insertStdItem(mt_UseCase_Folder);
         insertStdItem(mt_Actor);
         insertStdItem(mt_UseCase);
@@ -927,7 +968,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_EntityRelationship_Folder:
-        m_pInsert = new KPopupMenu(this,"New");
+        m_pInsert = new KPopupMenu(this);
         insertStdItem(mt_EntityRelationship_Folder);
         insertStdItem(mt_Entity);
         insertStdItem(mt_EntityRelationship_Diagram);
@@ -959,7 +1000,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
 
         //FIXME a lot of these insertItem()s could be insertStandardItem()s
     case mt_On_UseCase_Diagram:
-        m_pInsert = new KPopupMenu( this, "New" );
+        m_pInsert = new KPopupMenu( this );
         m_pInsert -> insertItem(m_pixmap[pm_Actor], i18n( "Actor..." ), mt_Actor );
         m_pInsert -> insertItem(m_pixmap[pm_Usecase], i18n( "Use Case..."), mt_UseCase );
         insertStdItem(mt_FloatText );
@@ -969,7 +1010,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_On_Class_Diagram:
-        m_pInsert = new KPopupMenu( this, "New" );
+        m_pInsert = new KPopupMenu( this );
         m_pInsert -> insertItem(m_pixmap[pm_Class], i18n("Class..."), mt_Class);
         m_pInsert->insertItem(m_pixmap[pm_Interface], i18n("Interface..."), mt_Interface);
         m_pInsert->insertItem(m_pixmap[pm_Datatype], i18n("Datatype..."), mt_Datatype);
@@ -982,7 +1023,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_On_State_Diagram:
-        m_pInsert = new KPopupMenu( this, "New" );
+        m_pInsert = new KPopupMenu( this );
         m_pInsert -> insertItem(m_pixmap[pm_InitialState], i18n("Initial State"), mt_Initial_State );
         m_pInsert -> insertItem(m_pixmap[pm_EndState], i18n("End State"), mt_End_State );
         m_pInsert -> insertItem(m_pixmap[pm_Usecase], i18n("State..."), mt_State );
@@ -993,7 +1034,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_On_Activity_Diagram:
-        m_pInsert = new KPopupMenu( this, "New" );
+        m_pInsert = new KPopupMenu( this );
         m_pInsert -> insertItem(m_pixmap[pm_InitialState], i18n("Initial Activity"), mt_Initial_Activity );
         m_pInsert -> insertItem(m_pixmap[pm_EndState], i18n("End Activity"), mt_End_Activity );
         m_pInsert -> insertItem(m_pixmap[pm_Usecase], i18n("Activity..."), mt_Activity );
@@ -1005,7 +1046,8 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_On_Component_Diagram:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
+        m_pInsert->insertItem(m_pixmap[pm_Subsystem], i18n("Subsystem..."), mt_Subsystem);
         m_pInsert->insertItem(m_pixmap[pm_Component], i18n("Component..."), mt_Component);
         m_pInsert->insertItem(m_pixmap[pm_Artifact], i18n("Artifact..."), mt_Artifact);
         insertFileNew();
@@ -1014,7 +1056,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_On_Deployment_Diagram:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
         m_pInsert->insertItem(m_pixmap[pm_Node], i18n("Node..."), mt_Node);
         insertFileNew();
         insertSeparator();
@@ -1022,7 +1064,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_On_EntityRelationship_Diagram:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
         m_pInsert->insertItem(m_pixmap[pm_Entity], i18n("Entity..."), mt_Entity);
         insertFileNew();
         insertSeparator();
@@ -1031,7 +1073,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
 
     case mt_On_Sequence_Diagram:
     case mt_On_Collaboration_Diagram:
-        m_pInsert = new KPopupMenu( this, "New" );
+        m_pInsert = new KPopupMenu( this );
         m_pInsert -> insertItem(m_pixmap[pm_Object], i18n("Object..."), mt_Object);
         insertStdItem(mt_FloatText);
         insertFileNew();
@@ -1040,7 +1082,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_Class:
-        m_pInsert = new KPopupMenu(this,"New");
+        m_pInsert = new KPopupMenu(this);
         m_pInsert -> insertItem(SmallIcon( "CVpublic_var"), i18n("Attribute"), mt_Attribute);
         m_pInsert -> insertItem(SmallIcon( "CVpublic_meth"), i18n("Operation"), mt_Operation);
         m_pInsert -> insertItem(SmallIcon("source"), i18n("Template"), mt_Template);
@@ -1050,7 +1092,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_Interface:
-        m_pInsert = new KPopupMenu(this,"New");
+        m_pInsert = new KPopupMenu(this);
         m_pInsert->insertItem(SmallIcon("CVpublic_meth"), i18n("Operation"), mt_Operation);
         m_pInsert -> insertItem(SmallIcon("source"), i18n("Template"), mt_Template);
         insertFileNew();
@@ -1059,7 +1101,7 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_Package:
-        m_pInsert = new KPopupMenu(this, "New");
+        m_pInsert = new KPopupMenu(this);
         insertContainerItems(false);
         insertStdItems();
         insertStdItem(mt_Properties);
@@ -1068,9 +1110,41 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         insertStdItem(mt_Collapse_All);
         break;
 
+    case mt_Subsystem:
+        m_pInsert = new KPopupMenu(this);
+        insertStdItem(mt_Subsystem);
+        insertStdItem(mt_Component);
+        insertStdItem(mt_Artifact);
+        insertFileNew();
+        insertStdItems();
+        insertStdItem(mt_Properties);
+        insertSeparator();
+        insertStdItem(mt_Expand_All);
+        insertStdItem(mt_Collapse_All);
+        break;
+
+    case mt_Component:
+        m_pInsert = new KPopupMenu(this);
+        insertStdItem(mt_Component);
+        insertStdItem(mt_Artifact);
+        insertFileNew();
+        insertStdItems();
+        insertStdItem(mt_Properties);
+        insertSeparator();
+        insertStdItem(mt_Expand_All);
+        insertStdItem(mt_Collapse_All);
+        break;
+
+    case mt_Entity:
+        m_pInsert = new KPopupMenu(this);
+        m_pInsert->insertItem(SmallIcon("source"), i18n("Entity Attribute..."), mt_EntityAttribute);
+        insertFileNew();
+        insertStdItems();
+        insertStdItem(mt_Properties);
+        break;
+
     case mt_Datatype:
     case mt_Enum:
-    case mt_Component:
     case mt_Node:
     case mt_Artifact:
     case mt_Actor:
@@ -1107,13 +1181,13 @@ void ListPopupMenu::setupMenu(Menu_Type type, UMLView* view) {
         break;
 
     case mt_New_Activity:
-        m_pInsert = new KPopupMenu(this,"New");
+        m_pInsert = new KPopupMenu(this);
         insertStdItem(mt_New_Activity);
         insertFileNew();
         break;
 
     case mt_Activity_Selected:
-        m_pInsert = new KPopupMenu(this,"New");
+        m_pInsert = new KPopupMenu(this);
         insertStdItem(mt_New_Activity);
         insertFileNew();
         insertStdItem(mt_Rename);
