@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2004-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -19,8 +19,10 @@
 
 // app includes
 #include "assocrules.h"
+#include "association.h"
 #include "associationwidget.h"
 #include "classifierwidget.h"
+#include "folder.h"
 #include "model_utils.h"
 #include "uml.h"
 #include "umlobject.h"
@@ -205,9 +207,13 @@ void ToolBarStateAssociation::addAssociationInViewAndDoc(AssociationWidget* a) {
     // append in view
     if (m_pUMLView->addAssociation(a, false)) {
         // if view went ok, then append in document
-        UMLApp::app()->getDocument()->addAssociation(a->getAssociation());
+        UMLAssociation *umla = a->getAssociation();
+        Uml::Model_Type m = Model_Utils::convert_DT_MT(m_pUMLView->getType());
+        UMLDoc *umldoc = UMLApp::app()->getDocument();
+        umla->setUMLPackage(umldoc->getRootFolder(m));
+        UMLApp::app()->getDocument()->addAssociation(umla);
     } else {
-        kdError() << "cannot addAssocInViewAndDoc(), deleting" << endl;
+        kError() << "cannot addAssocInViewAndDoc(), deleting" << endl;
         delete a;
     }
 }
