@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2003-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2003-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include <kdebug.h>
@@ -55,14 +52,6 @@ QString UMLRole::getMultiplicity() const {
     return m_Multi;
 }
 
-QString UMLRole::getName() const {
-    return m_Name;
-}
-
-QString UMLRole::getDoc() const {
-    return m_Doc;
-}
-
 void UMLRole::setObject (UMLObject *obj) {
     // because we will get the id of this role from the parent
     // object, we CANT allow UMLRoles to take other UMLRoles as
@@ -71,7 +60,7 @@ void UMLRole::setObject (UMLObject *obj) {
     // for the time being. -b.t.
     if(obj && dynamic_cast<UMLRole*>(obj))
     {
-        kdError()<<"ERROR: UMLRole cant setObject() to another UMLRole!, ignoring"<<endl;
+        kError()<<"ERROR: UMLRole cant setObject() to another UMLRole!, ignoring"<<endl;
         return;
     }
 
@@ -89,24 +78,10 @@ void UMLRole::setMultiplicity ( const QString &multi ) {
     emit modified();
 }
 
-void UMLRole::setName( const QString &roleName ) {
-    m_Name = roleName;
-    emit modified();
-}
-
-void UMLRole::setDoc( const QString &doc ) {
-    m_Doc = doc;
-    emit modified();
-}
-
 Uml::Role_Type UMLRole::getRole() {
     return m_role;
 }
 
-void UMLRole::setIdStr( const QString &idStr ) {
-    m_SecondaryId = idStr;
-}
-
 void UMLRole::init(UMLAssociation * parent, UMLObject * parentObj, Uml::Role_Type r) {
     m_BaseType = Uml::ot_Role;
     m_role = r;
@@ -125,7 +100,7 @@ void UMLRole::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
     if (m_pSecondary)
         roleElement.setAttribute( "type", ID2STR(m_pSecondary->getID()) );
     else
-        kdError() << "UMLRole::saveToXMI(id " << ID2STR(m_nId)
+        kError() << "UMLRole::saveToXMI(id " << ID2STR(m_nId)
         << "): m_pSecondary is NULL" << endl;
     if (!m_Multi.isEmpty())
         roleElement.setAttribute("multiplicity", m_Multi);
@@ -136,7 +111,7 @@ void UMLRole::saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) {
             roleElement.setAttribute("aggregation", "composite");
             break;
         case Uml::at_Aggregation:
-            roleElement.setAttribute("aggregation", "shared");
+            roleElement.setAttribute("aggregation", "aggregate");
             break;
         default:
             roleElement.setAttribute("aggregation", "none");
@@ -180,7 +155,7 @@ bool UMLRole::load( QDomElement & element ) {
     QString type = element.attribute("type", "");
     if (!type.isEmpty()) {
         if (!m_SecondaryId.isEmpty())
-            kdWarning() << "UMLRole::load: overwriting old m_SecondaryId \""
+            kWarning() << "UMLRole::load: overwriting old m_SecondaryId \""
             << m_SecondaryId << " with new value \""
             << type << "\"" << endl;
         m_SecondaryId = type;
@@ -270,9 +245,9 @@ bool UMLRole::load( QDomElement & element ) {
         }
     }
     if (!m_Multi.isEmpty())
-        kdDebug() << "UMLRole::load(" << m_Name << "): m_Multi is " << m_Multi << endl;
+        kDebug() << "UMLRole::load(" << m_Name << "): m_Multi is " << m_Multi << endl;
     if (m_SecondaryId.isEmpty()) {
-        kdError() << "UMLRole::load: type not given or illegal" << endl;
+        kError() << "UMLRole::load: type not given or illegal" << endl;
         return false;
     }
     UMLObject * obj;
@@ -294,15 +269,17 @@ bool UMLRole::load( QDomElement & element ) {
     // the component roles/linked items needs to be done in order to get things
     // right. *sigh* -b.t.
 
-    if (m_role == Uml::A) {  // setting association type from the role (A)
-        QString aggregation = element.attribute("aggregation", "none");
-        if (aggregation == "composite")
-            m_pAssoc->setAssocType(Uml::at_Composition);
-        else if (aggregation == "shared")
-            m_pAssoc->setAssocType(Uml::at_Aggregation);
-        /* else
-                m_pAssoc->setAssocType(Uml::at_Association);  */
-    }
+    // Setting association type from the role (A)
+    // Determination of the "aggregation" attribute used to be done only
+    // when (m_role == Uml::A) but some XMI writers (e.g. StarUML) place
+    // the aggregation attribute at role B.
+    // The role end with the aggregation unequal to "none" wins.
+    QString aggregation = element.attribute("aggregation", "none");
+    if (aggregation == "composite")
+        m_pAssoc->setAssocType(Uml::at_Composition);
+    else if (aggregation == "shared"       // UML1.3
+          || aggregation == "aggregate")   // UML1.4
+        m_pAssoc->setAssocType(Uml::at_Aggregation);
 
     if (!element.hasAttribute("isNavigable")) {
         /* Backward compatibility mode: In Umbrello version 1.3.x the
