@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef UMLVIEW_H
@@ -46,12 +46,12 @@ class KPrinter;
 class ToolBarState;
 class ToolBarStateFactory;
 
-/** The UMLView class provides the view widget for the UMLApp
- * instance.  The View instance inherits QWidget as a base class and
- * represents the view object of a KMainWindow. As UMLView is part of
- * the document-view model, it needs a reference to the document
- * object connected with it by the UMLApp class to manipulate and
- * display the document structure provided by the UMLDoc class.
+/**
+ * UMLView instances represent diagrams.
+ * The UMLApp instance manages a QWidgetStack of UMLView instances.
+ * The visible diagram is at the top of stack.
+ * The UMLView class inherits from QCanvasView and it owns the
+ * objects displayed on its related QCanvas (see m_WidgetList.)
  *
  * @author Paul Hensgen <phensgen@techie.com>
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
@@ -930,12 +930,8 @@ protected:
     /**
      * Contains the unique ID to allocate to a widget that needs an
      * ID for the view.  @ref ObjectWidgets are an example of this.
-     * NOTE: Currently this is an int although Uml::IDType is a string
-     *       (unless ID_USE_INT is defined.) Perhaps it should be changed
-     *       to Uml::IDType but then we need a unique string generator.
-     *       See also UMLDoc::m_uniqueID.
      */
-    int m_nLocalID;
+    Uml::IDType m_nLocalID;
 
     /**
      * The ID of the view.  Allocated by @ref UMLDoc
